package rai_serve

import (
	"github.com/beego/beego/v2/client/orm"
	"time"
)

// 权益服务明细表
type CygxRaiServeBill struct {
	BillId           int       `orm:"column(bill_id);pk" description:"服务明细主键ID"`
	Content          string    `comment:"服务内容说明"`
	ServeTypeId      int       `comment:"服务类型ID"`
	ServeTypeName    string    `comment:"服务类型"`
	UserId           int       `comment:"用户ID"`
	Mobile           string    `comment:"手机号"`
	Email            string    `comment:"邮箱"`
	CompanyId        int       `comment:"公司ID"`
	CompanyName      string    `comment:"公司名称"`
	RealName         string    `comment:"用户实际名称"`
	RegisterPlatform int       `comment:"来源 1小程序，2：网页"`
	ServeCount       float64   `comment:"服务量小计"`
	IsKp             int       `comment:"是否是KP,1:是、0：否"`
	SourceId         int       `comment:"来源ID"`
	Source           string    `comment:"来源 "`
	CreateTime       time.Time `comment:"创建时间"`
	ViewTime         string    `comment:"浏览时间"`
}

// Redis对列消息中的结构体
type RaiServeBillRedis struct {
	Content          string    `comment:"服务内容说明"`
	UserId           int       `comment:"用户ID"`
	ComapnyId        int       `comment:"公司ID"`
	SourceId         int       `comment:"来源ID"`
	Source           string    `comment:"来源"`
	RegisterPlatform int       `comment:"来源 1小程序，2：网页"`
	ViewTime         time.Time `comment:"浏览时间"`
}

// 添加
func AddCygxRaiServeBill(item *CygxRaiServeBill) (err error) {
	o := orm.NewOrm()
	_, err = o.Insert(item)
	return
}

func GetCygxRaiServeBillCountByUserAndSource(userId, sourceId int, source string) (count int, err error) {
	o := orm.NewOrm()
	sql := ` SELECT COUNT(1) AS count FROM  cygx_rai_serve_bill WHERE  user_id = ?  AND source_id = 2 AND  source = ?  `
	err = o.Raw(sql, userId, sourceId, source).QueryRow(&count)
	return
}

// 列表
func GetCygxRaiServeBillListAll(condition string, pars []interface{}) (items []*CygxRaiServeBill, err error) {
	if condition == "" {
		return
	}
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_rai_serve_bill   WHERE 1= 1 `
	if condition != "" {
		sql += condition
	}
	_, err = o.Raw(sql, pars).QueryRows(&items)
	return
}

// AddCygxRaiServeBillMulti 批量添加
func AddCygxRaiServeBillMulti(items []*CygxRaiServeBill) (err error) {
	if len(items) == 0 {
		return
	}
	o, err := orm.NewOrm().Begin()
	if err != nil {
		return
	}
	defer func() {
		if err == nil {
			o.Commit()
		} else {
			o.Rollback()
		}
	}()
	if len(items) > 0 {
		//批量添加流水信息
		_, err = o.InsertMulti(len(items), items)
	}
	return
}
