package rai_serve

import (
	"github.com/beego/beego/v2/client/orm"
	"time"
)

type CygxRaiServeCompany struct {
	ServeCompanyId    int       `comment:"ServeCompanyId 主键ID"`
	CompanyId         int       `comment:"公司ID"`
	CompanyName       string    `comment:"公司名称"`
	CreateTime        time.Time `comment:"创建时间"`
	Money             float64   `comment:"合同金额"`
	ServeCoverageRate string    `comment:"近四周服务覆盖率"`
	SellerId          int       `comment:"所属销售id"`
	SellerName        string    `comment:"所属销售名称"`
	StartDate         string    `comment:"开始日期"`
	EndDate           string    `comment:"结束日期"`
	ShareSeller       string    `comment:"共享销售"`
	ShareSellerId     int       `comment:"共享销售员id"`
	Status            string    `comment:"客户状态"`
	PermissionName    string    `comment:"权限名"`
}

func AddCygxRaiServeCompanyMulti(items []*CygxRaiServeCompany) (err error) {
	o, err := orm.NewOrm().Begin()
	if err != nil {
		return
	}
	defer func() {
		if err == nil {
			o.Commit()
		} else {
			o.Rollback()
		}
	}()

	//if len(deleteCompanyIds) > 0 {
	//删除不属于权益共享的公司
	sql := ` DELETE FROM cygx_rai_serve_company  `
	_, err = o.Raw(sql).Exec()
	if err != nil {
		return
	}
	//}

	//批量插入新的关联数据
	if len(items) > 0 {
		//批量添加流水信息
		_, err = o.InsertMulti(len(items), items)
	}

	return
}

// UpdateCygxRaiServeCompanyMulti 批量修改正式客户信息
func UpdateCygxRaiServeCompanyMulti(items []*CygxRaiServeCompany) (err error) {
	o := orm.NewOrm()
	p, err := o.Raw("UPDATE cygx_rai_serve_company SET money = ? ,serve_coverage_rate =? ,permission_name = ?  WHERE company_id = ?").Prepare()
	if err != nil {
		return
	}
	defer func() {
		_ = p.Close() // 别忘记关闭 statement
	}()
	for _, v := range items {
		_, err = p.Exec(v.Money, v.ServeCoverageRate, v.PermissionName, v.CompanyId)
		if err != nil {
			return
		}
	}
	return
}

// UpdateCygxRaiServeCompanyFormalNoMulti 批量修改非正式客户信息
func UpdateCygxRaiServeCompanyFormalNoMulti(items []*CygxRaiServeCompany) (err error) {
	o := orm.NewOrm()
	p, err := o.Raw("UPDATE cygx_rai_serve_company SET money = ? , serve_coverage_rate =? ,permission_name = ? , start_date = ? , end_date = ?  WHERE company_id = ?").Prepare()
	if err != nil {
		return
	}
	defer func() {
		_ = p.Close() // 别忘记关闭 statement
	}()
	for _, v := range items {
		_, err = p.Exec(v.Money, v.ServeCoverageRate, v.PermissionName, v.StartDate, v.EndDate, v.CompanyId)
		if err != nil {
			return
		}
	}
	return
}

// 获取当前所属权益服务公司表所有ID
func GetCygxRaiServeCompanyAllList() (items []*CygxRaiServeCompany, err error) {
	o := orm.NewOrm()
	sql := ` SELECT *  FROM	cygx_rai_serve_company LIMIT  1000  `
	_, err = o.Raw(sql).QueryRows(&items)
	return
}
