package services

import (
	"encoding/json"
	"errors"
	"fmt"
	"hongze/hongze_cygx/models"
	"hongze/hongze_cygx/models/company"
	"hongze/hongze_cygx/models/rai_serve"
	"hongze/hongze_cygx/utils"
	"strings"
	"time"
)

//权益服务统计

//func init() {
//	UpdateRaiServeCompany()
//}

// 更新现有的权益服务客户数据
func UpdateRaiServeCompany() (err error) {
	defer func() {
		if err != nil {
			fmt.Println(err)
			go utils.SendAlarmMsg("更新现有的权益服务客户数据失败 UpdateRaiServeCompany："+err.Error(), 2)
		}
	}()

	//获取当前所有的权益服务客户ID
	//listRaiServeCompanyId, e := rai_serve.GetCygxRaiServeCompanyAllList()
	//if e != nil {
	//	err = errors.New("GetCygxRaiServeCompanyAllList, Err: " + e.Error())
	//	return
	//}
	//mapOldCompanyId := make(map[int]bool) //原来的所属机构
	//mapNewCompanyId := make(map[int]bool) // 现有的所属机构
	//var deleteCompanyIds []int            // 需要删除的机构
	//for _, v := range listRaiServeCompanyId {
	//	mapOldCompanyId[v.CompanyId] = true
	//}

	var condition string
	var pars []interface{}
	condition = `    AND p.product_id = 2 AND  (p.group_id = ? OR  p.share_group_id = ?) `
	pars = append(pars, utils.RAI_SERVE_GROUP_ID, utils.RAI_SERVE_GROUP_ID)
	listCompanyProduct, e := company.GetCompanyProductAndCompanyListByCondition(condition, pars)
	if e != nil {
		err = errors.New("GetCompanyProductListByCondition, Err: " + e.Error())
		return
	}

	var items []*rai_serve.CygxRaiServeCompany
	for _, v := range listCompanyProduct {
		//mapNewCompanyId[v.CompanyId] = true
		//if mapOldCompanyId[v.CompanyId] {
		//	continue
		//}
		item := new(rai_serve.CygxRaiServeCompany)
		item.CompanyId = v.CompanyId
		item.CompanyName = v.CompanyName
		item.CreateTime = time.Now()
		//item.Money = 100
		//item.ServeCoverageRate = "66.66%"
		item.SellerId = v.SellerId
		item.SellerName = v.SellerName
		item.StartDate = v.StartDate
		item.EndDate = v.EndDate
		item.ShareSeller = v.ShareSeller
		item.ShareSellerId = v.ShareSellerId
		item.Status = v.Status
		//item.PermissionName = "科技"
		items = append(items, item)
	}

	//for _, v := range listRaiServeCompanyId {
	//	if !mapNewCompanyId[v.CompanyId] {
	//		deleteCompanyIds = append(deleteCompanyIds, v.CompanyId)
	//	}
	//}
	//先删除老的再添加新的
	e = rai_serve.AddCygxRaiServeCompanyMulti(items)
	if e != nil {
		err = errors.New("AddCygxRaiServeCompanyMulti, Err: " + e.Error())
		return
	}

	//listRaiServeCompanyNow, e := rai_serve.GetCygxRaiServeCompanyAllList()
	//if e != nil {
	//	err = errors.New("GetCygxRaiServeCompanyAllList_Now, Err: " + e.Error())
	//	return
	//}

	var formalCompanyIds []int   // 当前正式客户ID
	var formalNoCompanyIds []int // 当前非正式客户ID

	for _, v := range listCompanyProduct {
		if v.Status == "正式" {
			formalCompanyIds = append(formalCompanyIds, v.CompanyId)
		} else {
			formalNoCompanyIds = append(formalNoCompanyIds, v.CompanyId)
		}
	}

	var itemsUpdate []*rai_serve.CygxRaiServeCompany
	if len(formalCompanyIds) > 0 { //正式客户信息
		condition = ""
		pars = make([]interface{}, 0)
		condition = `    AND product_id = 2 AND company_id IN  (` + utils.GetOrmInReplace(len(formalCompanyIds)) + `) AND status = 1  AND  end_date > ? `
		pars = append(pars, formalCompanyIds, time.Now())
		listCompanyContract, e := company.GetCompanyContractList(condition, pars)
		if e != nil {
			err = errors.New("GetCompanyContractList, Err: " + e.Error())
			return
		}
		companyMoney := make(map[int]float64)
		for _, v := range listCompanyContract {
			companyMoney[v.CompanyId] += v.Money
		}

		permissionNameMapByCompanyId, e := GetCompanyReportPermissionNameMapByCompanyId(formalCompanyIds)
		if e != nil {
			err = errors.New("GetCompanyReportPermissionNameMapByCompanyId, Err: " + e.Error())
			return
		}
		for _, v := range formalCompanyIds {
			item := new(rai_serve.CygxRaiServeCompany)
			item.CompanyId = v
			item.Money = companyMoney[v]
			item.PermissionName = permissionNameMapByCompanyId[v]
			item.ServeCoverageRate = "61.8"
			itemsUpdate = append(itemsUpdate, item)
		}

		fmt.Println(companyMoney)
	}

	//正式客户数据修改
	e = rai_serve.UpdateCygxRaiServeCompanyMulti(itemsUpdate)
	if e != nil {
		err = errors.New("UpdateCygxRaiServeCompanyMulti, Err: " + e.Error())
		return
	}

	//非正式客户数据修改
	var itemsUpdateFormalNo []*rai_serve.CygxRaiServeCompany
	if len(formalNoCompanyIds) > 0 { //非正式客户信息
		condition = ""
		pars = make([]interface{}, 0)
		condition = `    AND product_id = 2 AND company_id IN  (` + utils.GetOrmInReplace(len(formalNoCompanyIds)) + `) AND status = 1  AND  end_date < ?  GROUP BY	company_id  ORDER BY	company_contract_id DESC `
		pars = append(pars, formalNoCompanyIds, time.Now())
		listCompanyContractLastId, e := company.GetCompanyContractLastList(condition, pars) //获取关联的最后一笔合同信息
		if e != nil {
			err = errors.New("GetCompanyContractLastList, Err: " + e.Error())
			return
		}
		var companyContractIds []int
		for _, v := range listCompanyContractLastId {
			companyContractIds = append(companyContractIds, v.CompanyContractId)
		}

		condition = ""
		pars = make([]interface{}, 0)
		condition = `    AND product_id = 2 AND company_id IN  (` + utils.GetOrmInReplace(len(formalNoCompanyIds)) + `) AND status = 1  AND company_contract_id IN  (` + utils.GetOrmInReplace(len(companyContractIds)) + `)   AND    end_date < ?  GROUP BY	company_id  ORDER BY	company_contract_id DESC `
		pars = append(pars, formalNoCompanyIds, companyContractIds, time.Now())
		listCompanyContractLast, e := company.GetCompanyContractList(condition, pars)
		if e != nil {
			err = errors.New("GetCompanyContractList, Err: " + e.Error())
			return
		}

		permissionNameMapByContractId, e := GetCompanyContractPermissionNameMapById(companyContractIds)
		if e != nil {
			err = errors.New("GetCompanyReportPermissionNameMapByCompanyId, Err: " + e.Error())
			return
		}
		fmt.Println("permissionNameMapByContractId", permissionNameMapByContractId)
		for _, v := range listCompanyContractLast {
			item := new(rai_serve.CygxRaiServeCompany)
			item.CompanyId = v.CompanyId
			item.Money = v.Money
			item.StartDate = v.StartDate
			item.EndDate = v.EndDate
			item.ServeCoverageRate = " 61.8"
			item.PermissionName = permissionNameMapByContractId[v.CompanyContractId]
			itemsUpdateFormalNo = append(itemsUpdateFormalNo, item)
		}
	}
	e = rai_serve.UpdateCygxRaiServeCompanyFormalNoMulti(itemsUpdateFormalNo)
	if e != nil {
		err = errors.New("UpdateCygxRaiServeCompanyFormalNoMulti, Err: " + e.Error())
		return
	}

	return
}

// GetCompanyContractPermissionNameMapById 获取合并之后的合同所对应的权限种类名称
func GetCompanyContractPermissionNameMapById(companyContractIds []int) (mapContractResp map[int]string, err error) {
	//return
	lenArr := len(companyContractIds)
	if lenArr == 0 {
		return
	}
	var condition string
	var pars []interface{}

	condition += " AND  company_contract_id IN (" + utils.GetOrmInReplace(lenArr) + ")"
	pars = append(pars, companyContractIds)

	//companyContractList, e := company.GetCompanyContractList(condition, pars)
	//if e != nil && e.Error() != utils.ErrNoRow() {
	//	err = errors.New("GetCompanyContractList, Err: " + e.Error())
	//	return
	//}

	permissionList, e := models.GetChartPermissionList()
	if e != nil && e.Error() != utils.ErrNoRow() {
		err = errors.New("GetChartPermissionList, Err: " + e.Error())
		return
	}
	mappermissionName := make(map[int]string)
	for _, v := range permissionList {
		if v.ProductId == 2 {
			mappermissionName[v.ChartPermissionId] = v.Remark
		}
	}

	mapContractIdPerssion := make(map[int]string) //单个合同ID所对应的套餐或者权限名称
	//for _, v := range companyContractList {
	//	if v.RaiPackageType == 1 {
	//		mapContractIdPerssion[v.CompanyContractId] = "70w套餐,"
	//	}
	//	if v.RaiPackageType == 2 {
	//		mapContractIdPerssion[v.CompanyContractId] = "45w套餐,"
	//	}
	//}

	companyContractPermissionList, e := company.GetCompanyContractPermissionList(condition, pars)
	if e != nil && e.Error() != utils.ErrNoRow() {
		err = errors.New("GetCompanyContractPermissionList, Err: " + e.Error())
		return
	}

	mapIsUpgrade := make(map[string]bool) //合同ID对应的行业是否有升级
	for _, v := range companyContractPermissionList {
		//如果开通的不是整个套餐，那么就做单独的子权限处理
		if strings.Count(mapContractIdPerssion[(v.CompanyContractId)], "w套餐") == 0 {
			if v.ChartPermissionId == utils.CHART_PERMISSION_ID_YANXUAN {
				if v.ExpensiveYx == 1 {
					mapContractIdPerssion[(v.CompanyContractId)] += utils.CHART_PERMISSION_NAME_MF_YANXUAN + "(5w),"
				} else if v.ExpensiveYx == 2 {
					mapContractIdPerssion[(v.CompanyContractId)] += utils.CHART_PERMISSION_NAME_MF_YANXUAN + "(10w),"
				} else {
					mapContractIdPerssion[(v.CompanyContractId)] += utils.CHART_PERMISSION_NAME_MF_YANXUAN + ","
				}
			} else {
				mapContractIdPerssion[(v.CompanyContractId)] += mappermissionName[v.ChartPermissionId] + ","
				if v.IsUpgrade == 1 {
					//合同ID，权限名称形成唯一的主键索引
					perssionName := mappermissionName[v.ChartPermissionId]
					perssionName = strings.Replace(perssionName, "(客观)", "", -1)
					perssionName = strings.Replace(perssionName, "(主观)", "", -1)
					mapIsUpgrade[fmt.Sprint(v.CompanyContractId, "perssionName", perssionName)] = true
				}
			}
		} else {
			if v.ChartPermissionId == utils.ZHUAN_JIA_ID {
				mapContractIdPerssion[(v.CompanyContractId)] += utils.ZHUAN_JIA_NAME + ","
			}
			if v.ChartPermissionId == utils.CHART_PERMISSION_ID_YANXUAN {
				if v.ExpensiveYx == 1 {
					mapContractIdPerssion[(v.CompanyContractId)] += utils.CHART_PERMISSION_NAME_MF_YANXUAN + "(5w),"
				} else if v.ExpensiveYx == 2 {
					mapContractIdPerssion[(v.CompanyContractId)] += utils.CHART_PERMISSION_NAME_MF_YANXUAN + "(10w),"
				} else {
					mapContractIdPerssion[(v.CompanyContractId)] += utils.CHART_PERMISSION_NAME_MF_YANXUAN + ","
				}
			}

			if v.ChartPermissionId == utils.YAN_XUAN_KOU_DIAN_BAO_ID {
				mapContractIdPerssion[(v.CompanyContractId)] += utils.YAN_XUAN_KOU_DIAN_BAO_NAME + ","
			}
		}
	}
	//合并客观权限
	for k, v := range mapContractIdPerssion {
		perssionName := v
		if strings.Count(v, utils.YI_YAO_NAME) == 2 {
			perssionName = strings.Replace(perssionName, "医药(主观)", "医药", -1)
			perssionName = strings.Replace(perssionName, "医药(客观)", "", -1)
		}
		if strings.Count(v, utils.XIAO_FEI_NAME) == 2 {
			perssionName = strings.Replace(perssionName, "消费(主观)", "消费", -1)
			perssionName = strings.Replace(perssionName, "消费(客观)", "", -1)
		}
		if strings.Count(v, utils.KE_JI_NAME) == 2 {
			perssionName = strings.Replace(perssionName, "科技(主观)", "科技", -1)
			perssionName = strings.Replace(perssionName, "科技(客观)", "", -1)
		}
		if strings.Count(v, utils.ZHI_ZAO_NAME) == 2 {
			perssionName = strings.Replace(perssionName, "智造(主观)", "智造", -1)
			perssionName = strings.Replace(perssionName, "智造(客观)", "", -1)
		}

		perssionName = strings.TrimRight(perssionName, ",")
		mapContractIdPerssion[k] = perssionName
	}
	mapContractResp = make(map[int]string, 0)

	//过滤多余的","
	for k, v := range mapContractIdPerssion {
		sliceName := strings.Split(v, ",")
		var nameArr []string
		for _, vName := range sliceName {
			if vName == "" {
				continue
			}
			if mapIsUpgrade[fmt.Sprint(k, "perssionName", vName)] {
				vName += "(升级)"
			}
			nameArr = append(nameArr, vName)
		}
		mapContractResp[k] = strings.Join(nameArr, ",")
	}
	return
}

// 根据公司ID获取目前行业所对应的正式权限
func GetCompanyReportPermissionNameMapByCompanyId(companyIds []int) (mapContractResp map[int]string, err error) {
	lenArr := len(companyIds)
	if lenArr == 0 {
		return
	}
	var condition string
	var pars []interface{}

	condition += " AND  company_id IN (" + utils.GetOrmInReplace(lenArr) + ") AND product_id = 2 AND status = '正式' "
	pars = append(pars, companyIds)

	permissionList, e := models.GetChartPermissionList()
	if e != nil && e.Error() != utils.ErrNoRow() {
		err = errors.New("GetChartPermissionList, Err: " + e.Error())
		return
	}
	mappermissionName := make(map[int]string)
	for _, v := range permissionList {
		if v.ProductId == 2 {
			mappermissionName[v.ChartPermissionId] = v.Remark
		}
	}

	mapContractIdPerssion := make(map[int]string) //单个合同ID所对应的套餐或者权限名称

	companyReportPermissionList, e := models.GetCompanyReportPermissionList(condition, pars)
	if e != nil && e.Error() != utils.ErrNoRow() {
		err = errors.New("GetCompanyReportPermissionList, Err: " + e.Error())
		return
	}

	mapIsUpgrade := make(map[string]bool) //合同ID对应的行业是否有升级
	for _, v := range companyReportPermissionList {
		//如果开通的不是整个套餐，那么就做单独的子权限处理
		if strings.Count(mapContractIdPerssion[(v.CompanyId)], "w套餐") == 0 {
			if v.ChartPermissionId == utils.CHART_PERMISSION_ID_YANXUAN {
				if v.ExpensiveYx == 1 {
					mapContractIdPerssion[(v.CompanyId)] += utils.CHART_PERMISSION_NAME_MF_YANXUAN + "(5w),"
				} else if v.ExpensiveYx == 2 {
					mapContractIdPerssion[(v.CompanyId)] += utils.CHART_PERMISSION_NAME_MF_YANXUAN + "(10w),"
				} else {
					mapContractIdPerssion[(v.CompanyId)] += utils.CHART_PERMISSION_NAME_MF_YANXUAN + ","
				}
			} else {
				mapContractIdPerssion[(v.CompanyId)] += mappermissionName[v.ChartPermissionId] + ","
				if v.IsUpgrade == 1 {
					//合同ID，权限名称形成唯一的主键索引
					perssionName := mappermissionName[v.ChartPermissionId]
					perssionName = strings.Replace(perssionName, "(客观)", "", -1)
					perssionName = strings.Replace(perssionName, "(主观)", "", -1)
					mapIsUpgrade[fmt.Sprint(v.CompanyId, "perssionName", perssionName)] = true
				}
			}
		} else {
			if v.ChartPermissionId == utils.ZHUAN_JIA_ID {
				mapContractIdPerssion[(v.CompanyId)] += utils.ZHUAN_JIA_NAME + ","
			}
			if v.ChartPermissionId == utils.CHART_PERMISSION_ID_YANXUAN {
				if v.ExpensiveYx == 1 {
					mapContractIdPerssion[(v.CompanyId)] += utils.CHART_PERMISSION_NAME_MF_YANXUAN + "(5w),"
				} else if v.ExpensiveYx == 2 {
					mapContractIdPerssion[(v.CompanyId)] += utils.CHART_PERMISSION_NAME_MF_YANXUAN + "(10w),"
				} else {
					mapContractIdPerssion[(v.CompanyId)] += utils.CHART_PERMISSION_NAME_MF_YANXUAN + ","
				}
			}

			if v.ChartPermissionId == utils.YAN_XUAN_KOU_DIAN_BAO_ID {
				mapContractIdPerssion[(v.CompanyId)] += utils.YAN_XUAN_KOU_DIAN_BAO_NAME + ","
			}
		}
	}
	//合并客观权限
	for k, v := range mapContractIdPerssion {
		perssionName := v
		if strings.Count(v, utils.YI_YAO_NAME) == 2 {
			perssionName = strings.Replace(perssionName, "医药(主观)", "医药", -1)
			perssionName = strings.Replace(perssionName, "医药(客观)", "", -1)
		}
		if strings.Count(v, utils.XIAO_FEI_NAME) == 2 {
			perssionName = strings.Replace(perssionName, "消费(主观)", "消费", -1)
			perssionName = strings.Replace(perssionName, "消费(客观)", "", -1)
		}
		if strings.Count(v, utils.KE_JI_NAME) == 2 {
			perssionName = strings.Replace(perssionName, "科技(主观)", "科技", -1)
			perssionName = strings.Replace(perssionName, "科技(客观)", "", -1)
		}
		if strings.Count(v, utils.ZHI_ZAO_NAME) == 2 {
			perssionName = strings.Replace(perssionName, "智造(主观)", "智造", -1)
			perssionName = strings.Replace(perssionName, "智造(客观)", "", -1)
		}

		perssionName = strings.TrimRight(perssionName, ",")
		mapContractIdPerssion[k] = perssionName
	}
	mapContractResp = make(map[int]string, 0)

	//过滤多余的","
	for k, v := range mapContractIdPerssion {
		sliceName := strings.Split(v, ",")
		var nameArr []string
		for _, vName := range sliceName {
			if vName == "" {
				continue
			}
			if mapIsUpgrade[fmt.Sprint(k, "perssionName", vName)] {
				vName += "(升级)"
			}
			nameArr = append(nameArr, vName)
		}
		mapContractResp[k] = strings.Join(nameArr, ",")
	}
	return
}

// Redis对列消息中的结构体
type RaiServeBillRedis struct {
	Content          string    `comment:"服务内容说明"`
	UserId           int       `comment:"用户ID"`
	ComapnyId        int       `comment:"公司ID"`
	SourceId         int       `comment:"来源ID"`
	Source           string    `comment:"来源"`
	RegisterPlatform int       `comment:"来源 1小程序，2：网页"`
	ViewTime         time.Time `comment:"浏览时间"`
}

// 权益服务统计添加到Redis队列中
func CygxRaiServeBillRedisAdd(content, source string, userId, comapnyId, sourceId, registerPlatform int, viewTime time.Time) (err error) {
	defer func() {
		if err != nil {
			fmt.Println(err)
			msg := fmt.Sprint("source:", source, "userId:", userId, "sourceId", sourceId)
			go utils.SendAlarmMsg("权益服务统计添加到Redis队列中，写入Redis队列消息失败 CygxRaiServeBillRedisAdd："+err.Error()+msg, 2)
		}
	}()
	log := &rai_serve.RaiServeBillRedis{Content: content, Source: source, UserId: userId, ComapnyId: comapnyId, SourceId: sourceId, RegisterPlatform: registerPlatform, ViewTime: viewTime}
	if utils.Re == nil {
		err := utils.Rc.LPush(utils.CYGX_RAI_SERVE_BILL_KEY, log)
		if err != nil {
			fmt.Println("RaiServeBillRedis LPush Err:" + err.Error())
		}
	}
	return
}

//func init() {
//	CygxRaiServeBillRedisAddReduce()
//}

// CygxRaiServeBillRedisAddReduce 处理权益服务统计
func CygxRaiServeBillRedisAddReduce() (err error) {
	for {
		//SourceType int       `description:"1：报名、 2：取消报名、3：活动编辑、4：活动发布，取消发布、5：活动到会。"`
		utils.Rc.Brpop(utils.CYGX_RAI_SERVE_BILL_KEY, func(b []byte) {
			var log rai_serve.RaiServeBillRedis
			if err := json.Unmarshal(b, &log); err != nil {
				fmt.Println("json unmarshal wrong!")
				go utils.SendAlarmMsg("处理权益服务统计Redis队列消息失败："+err.Error()+string(b), 2)
			}
			//如果不是共享给 权益服务组的，则不处理
			taotalRaiServe, err := company.GetCompanyProductAaiServeCount(log.ComapnyId, utils.RAI_SERVE_GROUP_ID)
			if err != nil {
				go utils.SendAlarmMsg("处理权益服务统计Redis队列消息失败：GetCompanyProductAaiServeCount"+err.Error()+string(b), 2)
			}
			fmt.Println("taotaRaiServe", taotalRaiServe)
			if taotalRaiServe == 0 {
				return
			}

			//如果已经有记录了就不处理
			taotalSource, err := rai_serve.GetCygxRaiServeBillCountByUserAndSource(log.UserId, log.SourceId, log.Source)
			if err != nil {
				go utils.SendAlarmMsg("处理权益服务统计Redis队列消息失败：GetCygxRaiServeBillCountByUserAndSource"+err.Error()+string(b), 2)
			}
			if taotalSource > 0 {
				return
			}
			switch log.Source {
			case utils.CYGX_OBJ_YANXUANSPECIAL: //研选专栏阅读记录处理
				go RaiServeBillRedisAddReduceByYanxuanspecial(log)
				fmt.Println("研选专栏阅读记录处理")
				break

			default:
				fmt.Println(string(b))
				go utils.SendAlarmMsg("处理研选活动扣点处理Redis队列消息失败："+string(b), 2)
			}
		})
	}
}

// 处理权益服务统计->研选阅读记录
func RaiServeBillRedisAddReduceByYanxuanspecial(log rai_serve.RaiServeBillRedis) (err error) {
	source := log.Source
	userId := log.UserId
	sourceId := log.SourceId
	defer func() {
		if err != nil {
			go utils.SendAlarmMsg("用户报名活动扣点，处理Redis队列消息失败："+err.Error()+fmt.Sprint("source:", source, "userId:", userId, "sourceId", sourceId), 2)
		}
	}()
	wxUser, e := models.GetWxUserItemByUserId(userId)
	if e != nil {
		err = errors.New("GetWxUserItemByUserId, Err: " + e.Error())
		return
	}
	item := new(rai_serve.CygxRaiServeBill)
	item.Content = log.Content
	item.ServeTypeId = 5
	item.ServeTypeName = "阅读uv"
	item.UserId = wxUser.UserId
	item.Mobile = wxUser.Mobile
	item.Email = wxUser.Email
	item.CompanyId = wxUser.CompanyId
	item.CompanyName = wxUser.CompanyName
	item.RealName = wxUser.RealName
	item.RegisterPlatform = log.RegisterPlatform
	item.ServeCount = 0.5

	if wxUser.IsMaker == 1 {
		item.IsKp = wxUser.IsMaker
		item.ServeCount = item.ServeCount * 3
	}
	item.SourceId = log.SourceId
	item.Source = log.Source
	item.CreateTime = time.Now()
	item.ViewTime = log.ViewTime.Format(utils.FormatDateTime)
	err = rai_serve.AddCygxRaiServeBill(item)
	return
}

func init() {
	UpdateCygxRaiServeBillByCompanyIds()
}

// 批量更新企业服务明细记录
func UpdateCygxRaiServeBillByCompanyIds() (err error) {
	defer func() {
		if err != nil {
			fmt.Println(err)
			go utils.SendAlarmMsg("批量更新企业服务明细记录失败： UpdateCygxRaiServeBillByCompanyIds Err"+err.Error(), 2)
		}
	}()
	companyList, e := rai_serve.GetCygxRaiServeCompanyAllList()
	if e != nil {
		err = errors.New("GetCygxRaiServeCompanyAllList, Err: " + e.Error())
		return
	}
	var companyIds []int
	var items []*rai_serve.CygxRaiServeBill
	for _, v := range companyList {
		companyIds = append(companyIds, v.CompanyId)
	}

	lencompanyId := len(companyIds)

	listisMakeruser, e := models.GetWxUserisMakerByCompanyIds(companyIds)
	if e != nil {
		err = errors.New("GetWxUserisMakerByCompanyIds, Err: " + e.Error())
		return
	}
	mapUserMaker := make(map[int]bool)
	for _, v := range listisMakeruser {
		mapUserMaker[v.UserId] = true
	}
	fmt.Println(mapUserMaker)

	var condition string
	var pars []interface{}
	createTime := time.Now().AddDate(0, 0, -80) // 查询12周以内的数据

	condition = " AND  company_id IN  (" + utils.GetOrmInReplace(lencompanyId) + ")  AND create_time > ?  "
	pars = append(pars, companyIds, createTime)

	//研选专栏阅读记录内容
	{
		listYanxuanSpecialRecord, e := models.GetCygxYanxuanSpecialRecordRespListAll(condition+"  GROUP BY user_id, yanxuan_special_id  ORDER BY create_time ASC ", pars)
		if e != nil {
			err = errors.New("GetCygxYanxuanSpecialRecordRespListAll, Err: " + e.Error())
			return
		}

		var yanxuanspecialIds []int
		for _, v := range listYanxuanSpecialRecord {
			yanxuanspecialIds = append(yanxuanspecialIds, v.YanxuanSpecialId)
		}

		var conditionYanxuanSpecial string
		var parsYanxuanSpecial []interface{}
		conditionYanxuanSpecial += `  AND  id  IN (` + utils.GetOrmInReplace(len(yanxuanspecialIds)) + `) `
		parsYanxuanSpecial = append(parsYanxuanSpecial, yanxuanspecialIds)
		listYanxuanSpecial, e := models.GetYanxuanSpecialListBycondition(conditionYanxuanSpecial, parsYanxuanSpecial, 0, len(yanxuanspecialIds))
		if e != nil && e.Error() != utils.ErrNoRow() {
			err = errors.New("GetYanxuanSpecialListBycondition, Err: " + e.Error())
			return
		}
		mapYanxuanSpecialTitle := make(map[int]string)

		for _, v := range listYanxuanSpecial {
			mapYanxuanSpecialTitle[v.Id] = v.Title
		}

		//研选阅读明细
		var conditionBill string
		var parsBill []interface{}
		conditionBill = " AND source = 'yanxuanspecial' AND   company_id IN  (" + utils.GetOrmInReplace(lencompanyId) + ")  AND view_time > ?  "
		parsBill = append(parsBill, companyIds, createTime)
		listBillByYanxuanspecial, e := rai_serve.GetCygxRaiServeBillListAll(conditionBill, parsBill)
		if e != nil {
			err = errors.New("GetCygxRaiServeBillListAll, Err: " + e.Error())
			return
		}

		mapYanxuanspecialBill := make(map[string]bool)
		for _, v := range listBillByYanxuanspecial {
			mapYanxuanspecialBill[fmt.Sprint("UID_", v.UserId, "SID_", v.SourceId)] = true
		}

		for _, v := range listYanxuanSpecialRecord {
			if mapYanxuanspecialBill[fmt.Sprint("UID_", v.UserId, "SID_", v.YanxuanSpecialId)] { // 如果内容存在就不插入
				continue
			}
			item := new(rai_serve.CygxRaiServeBill)
			item.Content = mapYanxuanSpecialTitle[v.YanxuanSpecialId]
			item.ServeTypeId = 5
			item.ServeTypeName = "阅读uv"
			item.UserId = v.UserId
			item.Mobile = v.Mobile
			item.Email = v.Email
			item.CompanyId = v.CompanyId
			item.CompanyName = v.CompanyName
			item.RealName = v.RealName
			item.RegisterPlatform = v.RegisterPlatform
			item.ServeCount = 0.5

			if mapUserMaker[v.UserId] {
				item.IsKp = 1
				item.ServeCount = item.ServeCount * 3
			}
			item.SourceId = v.YanxuanSpecialId
			item.Source = utils.CYGX_OBJ_YANXUANSPECIAL
			item.CreateTime = time.Now()
			item.ViewTime = v.CreateTime
			items = append(items, item)
		}
	}
	//研选专栏阅读记录内容end

	//文章阅读记录内容
	{
		listArticleRecord, e := models.GetCygxArticleHistoryRecordAllListNoLimit(condition+"  GROUP BY user_id, article_id  ORDER BY create_time ASC ", pars)
		if e != nil {
			err = errors.New("GetCygxArticleHistoryRecordAllListNoLimit, Err: " + e.Error())
			return
		}
		//return
		var articleIds []int
		for _, v := range listArticleRecord {
			articleIds = append(articleIds, v.ArticleId)
		}

		var conditionArticle string
		var parsArticle []interface{}
		conditionArticle += `  AND  article_id  IN (` + utils.GetOrmInReplace(len(articleIds)) + `) `
		parsArticle = append(parsArticle, articleIds)
		listArticle, e := models.GetCygxCygxArticleList(conditionArticle, parsArticle, 0, len(articleIds))
		if e != nil && e.Error() != utils.ErrNoRow() {
			err = errors.New("GetCygxCygxArticleList, Err: " + e.Error())
			return
		}
		mapArticleTitle := make(map[int]string)

		for _, v := range listArticle {
			mapArticleTitle[v.ArticleId] = v.Title
		}
		fmt.Println(mapArticleTitle[10080])
		//return

		//文章阅读明细
		var conditionBill string
		var parsBill []interface{}
		conditionBill = " AND source = 'article' AND   company_id IN  (" + utils.GetOrmInReplace(lencompanyId) + ")  AND view_time > ?  "
		parsBill = append(parsBill, companyIds, createTime)
		listBillByArticle, e := rai_serve.GetCygxRaiServeBillListAll(conditionBill, parsBill)
		if e != nil {
			err = errors.New("GetCygxRaiServeBillListAll, Err: " + e.Error())
			return
		}

		mapArticleBill := make(map[string]bool)
		for _, v := range listBillByArticle {
			mapArticleBill[fmt.Sprint("UID_", v.UserId, "SID_", v.SourceId)] = true
		}

		for _, v := range listArticleRecord {
			if mapArticleBill[fmt.Sprint("UID_", v.UserId, "SID_", v.ArticleId)] { // 如果内容存在就不插入
				continue
			}
			item := new(rai_serve.CygxRaiServeBill)
			item.Content = mapArticleTitle[v.ArticleId]
			item.ServeTypeId = 5
			item.ServeTypeName = "阅读uv"
			item.UserId = v.UserId
			item.Mobile = v.Mobile
			item.Email = v.Email
			item.CompanyId = v.CompanyId
			item.CompanyName = v.CompanyName
			item.RealName = v.RealName
			item.RegisterPlatform = v.RegisterPlatform
			item.ServeCount = 0.5

			if mapUserMaker[v.UserId] {
				item.IsKp = 1
				item.ServeCount = item.ServeCount * 3
			}
			item.SourceId = v.ArticleId
			item.Source = utils.CYGX_OBJ_ARTICLE
			item.CreateTime = time.Now()
			item.ViewTime = v.CreateTime
			items = append(items, item)
		}
	}
	//文章阅读记录内容 end

	//活动记录内容
	{
		condition = " AND  art.company_id IN  (" + utils.GetOrmInReplace(lencompanyId) + ")  AND a.activity_time > ?  "
		signUpDetailList, e := models.GetSignupDetailBySignupjoinactivity(condition+"  ORDER BY a.activity_time ASC ", pars)
		if e != nil {
			err = errors.New("GetSignupDetailBySignupjoinactivity, Err: " + e.Error())
			return
		}

		//文章阅读明细
		var conditionBill string
		var parsBill []interface{}
		conditionBill = " AND source = 'activity' AND   company_id IN  (" + utils.GetOrmInReplace(lencompanyId) + ")  AND view_time > ?  "
		parsBill = append(parsBill, companyIds, createTime)
		listBillByArticle, e := rai_serve.GetCygxRaiServeBillListAll(conditionBill, parsBill)
		if e != nil {
			err = errors.New("GetCygxRaiServeBillListAll, Err: " + e.Error())
			return
		}

		mapArticleBill := make(map[string]bool)
		for _, v := range listBillByArticle {
			mapArticleBill[fmt.Sprint("UID_", v.UserId, "SID_", v.SourceId)] = true
		}

		for _, v := range signUpDetailList {
			if mapArticleBill[fmt.Sprint("UID_", v.UserId, "SID_", v.ActivityId)] { // 如果内容存在就不插入
				continue
			}
			item := new(rai_serve.CygxRaiServeBill)
			item.Content = v.ActivityName
			if v.ActivityType == 1 {
				item.ServeTypeId = 1
				item.ServeTypeName = "线上活动"
			} else {
				item.ServeTypeId = 2
				item.ServeTypeName = "线下活动"
			}
			item.UserId = v.UserId
			item.Mobile = v.Mobile
			item.Email = v.Email
			item.CompanyId = v.CompanyId
			item.CompanyName = v.CompanyName
			item.RealName = v.RealName
			//item.RegisterPlatform = v.RegisterPlatform
			item.ServeCount = 1
			if mapUserMaker[v.UserId] {
				item.IsKp = 1
				item.ServeCount = item.ServeCount * 3
			}
			item.SourceId = v.ActivityId
			item.Source = utils.CYGX_OBJ_ACTIVITY
			item.CreateTime = time.Now()
			item.ViewTime = v.ActivityTime
			items = append(items, item)
		}
	}
	//活动记录内容 end

	//专项调研活动记录内容
	{
		condition = " AND  art.company_id IN  (" + utils.GetOrmInReplace(lencompanyId) + ")  AND a.activity_time > ?  "
		activitySpecialList, e := models.GetCygxActivitySpecialMeetingDetailList(condition+"  ORDER BY a.activity_time ASC ", pars)
		if e != nil {
			err = errors.New("GetCygxActivitySpecialMeetingDetailList, Err: " + e.Error())
			return
		}

		//专项调研活动明细
		var conditionBill string
		var parsBill []interface{}
		conditionBill = " AND source = 'activityspecial' AND   company_id IN  (" + utils.GetOrmInReplace(lencompanyId) + ")  AND view_time > ?  "
		parsBill = append(parsBill, companyIds, createTime)
		listBillByArticle, e := rai_serve.GetCygxRaiServeBillListAll(conditionBill, parsBill)
		if e != nil {
			err = errors.New("GetCygxRaiServeBillListAll, Err: " + e.Error())
			return
		}

		mapArticleBill := make(map[string]bool)
		for _, v := range listBillByArticle {
			mapArticleBill[fmt.Sprint("UID_", v.UserId, "SID_", v.SourceId)] = true
		}

		for _, v := range activitySpecialList {
			if mapArticleBill[fmt.Sprint("UID_", v.UserId, "SID_", v.ActivityId)] { // 如果内容存在就不插入
				continue
			}
			item := new(rai_serve.CygxRaiServeBill)
			item.Content = v.ResearchTheme
			item.ServeTypeId = 3
			item.ServeTypeName = "专项调研"
			item.UserId = v.UserId
			item.Mobile = v.Mobile
			item.Email = v.Email
			item.CompanyId = v.CompanyId
			item.CompanyName = v.CompanyName
			item.RealName = v.RealName
			//item.RegisterPlatform = v.RegisterPlatform
			item.ServeCount = 1
			if mapUserMaker[v.UserId] {
				item.IsKp = 1
				item.ServeCount = item.ServeCount * 3
			}
			item.SourceId = v.ActivityId
			item.Source = utils.CYGX_OBJ_ACTIVITYSPECIAL
			item.CreateTime = time.Now()
			item.ViewTime = v.ActivityTime
			items = append(items, item)
		}
	}
	//专项调研活动记录内容 end

	//1v1路演
	{
		condition = " AND  art.company_id IN  (" + utils.GetOrmInReplace(lencompanyId) + ")  AND a.activity_time > ?  "
		activitySpecialList, e := models.GetCygxActivitySpecialMeetingDetailList(condition+"  ORDER BY a.activity_time ASC ", pars)
		if e != nil {
			err = errors.New("GetCygxActivitySpecialMeetingDetailList, Err: " + e.Error())
			return
		}

		//专项调研活动明细
		var conditionBill string
		var parsBill []interface{}
		conditionBill = " AND source = 'activityspecial' AND   company_id IN  (" + utils.GetOrmInReplace(lencompanyId) + ")  AND view_time > ?  "
		parsBill = append(parsBill, companyIds, createTime)
		listBillByArticle, e := rai_serve.GetCygxRaiServeBillListAll(conditionBill, parsBill)
		if e != nil {
			err = errors.New("GetCygxRaiServeBillListAll, Err: " + e.Error())
			return
		}

		mapArticleBill := make(map[string]bool)
		for _, v := range listBillByArticle {
			mapArticleBill[fmt.Sprint("UID_", v.UserId, "SID_", v.SourceId)] = true
		}

		for _, v := range activitySpecialList {
			if mapArticleBill[fmt.Sprint("UID_", v.UserId, "SID_", v.ActivityId)] { // 如果内容存在就不插入
				continue
			}
			item := new(rai_serve.CygxRaiServeBill)
			item.Content = v.ResearchTheme
			item.ServeTypeId = 3
			item.ServeTypeName = "专项调研"
			item.UserId = v.UserId
			item.Mobile = v.Mobile
			item.Email = v.Email
			item.CompanyId = v.CompanyId
			item.CompanyName = v.CompanyName
			item.RealName = v.RealName
			//item.RegisterPlatform = v.RegisterPlatform
			item.ServeCount = 1
			if mapUserMaker[v.UserId] {
				item.IsKp = 1
				item.ServeCount = item.ServeCount * 3
			}
			item.SourceId = v.ActivityId
			item.Source = utils.CYGX_OBJ_ACTIVITYSPECIAL
			item.CreateTime = time.Now()
			item.ViewTime = v.ActivityTime
			items = append(items, item)
		}
	}
	//1v1路演 end

	fmt.Println(len(items))
	e = rai_serve.AddCygxRaiServeBillMulti(items)
	if e != nil {
		err = errors.New("AddCygxRaiServeBillMulti, Err: " + e.Error())
		return
	}

	return
}
